AuthenticationReadinessOutcome class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → AuthenticationReadinessOutcome?
Constants
- AUTHENTICATION_READINESS_OUTCOME_OBSERVATION_ROUNDS_EXHAUSTED → const AuthenticationReadinessOutcome
- AUTHENTICATION_READINESS_OUTCOME_PATIENCE_EXHAUSTED → const AuthenticationReadinessOutcome
- AUTHENTICATION_READINESS_OUTCOME_READY → const AuthenticationReadinessOutcome
- AUTHENTICATION_READINESS_OUTCOME_UNSPECIFIED → const AuthenticationReadinessOutcome
-
values
→ const List<
AuthenticationReadinessOutcome>