BirthCertificate class
Signed authority evidence for one child birth. This is a kernel input, not tenant payload: generated clients cannot accidentally rename it, domain law cannot interpret it as business data, and the kernel converts it directly into its nominal Rust certificate before attaching it to USDA.
- Available extensions
Constructors
-
BirthCertificate({String? child, String? founder, bool? verified, List<
int> ? parentKey, String? parentId, Int64? epoch, List<int> ? signature, String? verifiedVia, String? idpToken, Int64? capturedClock, String? authProviderIssuer, String? authProviderJwks, String? authProviderAudience}) -
factory
-
BirthCertificate.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- BirthCertificate.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- authProviderAudience ↔ String
-
getter/setter pair
- authProviderIssuer ↔ String
-
getter/setter pair
- authProviderJwks ↔ String
-
getter/setter pair
- capturedClock ↔ Int64
-
getter/setter pair
- child ↔ String
-
getter/setter pair
- epoch ↔ Int64
-
getter/setter pair
- founder ↔ String
-
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- idpToken ↔ String
-
getter/setter pair
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - parentId ↔ String
-
getter/setter pair
-
parentKey
↔ List<
int> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
signature
↔ List<
int> -
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- verified ↔ bool
-
getter/setter pair
- verifiedVia ↔ String
-
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAuthProviderAudience(
) → void -
clearAuthProviderIssuer(
) → void -
clearAuthProviderJwks(
) → void -
clearCapturedClock(
) → void -
clearChild(
) → void -
clearEpoch(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearFounder(
) → void -
clearIdpToken(
) → void -
clearParentId(
) → void -
clearParentKey(
) → void -
clearSignature(
) → void -
clearVerified(
) → void -
clearVerifiedVia(
) → void -
clone(
) → BirthCertificate - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(BirthCertificate)) → BirthCertificate -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → BirthCertificate - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAuthProviderAudience(
) → bool -
hasAuthProviderIssuer(
) → bool -
hasAuthProviderJwks(
) → bool -
hasCapturedClock(
) → bool -
hasChild(
) → bool -
hasEpoch(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasFounder(
) → bool -
hasIdpToken(
) → bool -
hasParentId(
) → bool -
hasParentKey(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasSignature(
) → bool -
hasVerified(
) → bool -
hasVerifiedVia(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited