CallRequest class

Available extensions

Constructors

CallRequest({int? protocolVersion, String? requestId, OpenRequest? open, OfferRequest? offer, QueryRequest? query, OutboxRequest? outbox, SyncRequest? sync, CustodyRequest? custody, KernelConfigurationRequest? configure, SignPreparedOfferRequest? signPreparedOffer, PrepareRemoteOfferRequest? prepareRemoteOffer, SignOfferPreparationRequest? signOfferPreparation, SignBirthCertificateRequest? signBirthCertificate, SigningIdentityRequest? signingIdentity, SignAuthorityAttestationRequest? signAuthorityAttestation, MintTypedIdRequest? mintTypedId, EncryptionIdentityRequest? encryptionIdentity, WrapScopeKeyRequest? wrapScopeKey, UnwrapScopeKeyRequest? unwrapScopeKey})
factory
CallRequest.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
CallRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

configure ↔ KernelConfigurationRequest
getter/setter pair
custody ↔ CustodyRequest
getter/setter pair
encryptionIdentity ↔ EncryptionIdentityRequest
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
mintTypedId ↔ MintTypedIdRequest
getter/setter pair
offer ↔ OfferRequest
getter/setter pair
open ↔ OpenRequest
getter/setter pair
outbox ↔ OutboxRequest
getter/setter pair
prepareRemoteOffer ↔ PrepareRemoteOfferRequest
getter/setter pair
protocolVersion ↔ int
getter/setter pair
query ↔ QueryRequest
getter/setter pair
requestId ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signAuthorityAttestation ↔ SignAuthorityAttestationRequest
getter/setter pair
signBirthCertificate ↔ SignBirthCertificateRequest
getter/setter pair
signingIdentity ↔ SigningIdentityRequest
getter/setter pair
signOfferPreparation ↔ SignOfferPreparationRequest
getter/setter pair
signPreparedOffer ↔ SignPreparedOfferRequest
getter/setter pair
sync ↔ SyncRequest
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
unwrapScopeKey ↔ UnwrapScopeKeyRequest
getter/setter pair
wrapScopeKey ↔ WrapScopeKeyRequest
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearConfigure() → void
clearCustody() → void
clearEncryptionIdentity() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearMintTypedId() → void
clearOffer() → void
clearOpen() → void
clearOperation() → void
clearOutbox() → void
clearPrepareRemoteOffer() → void
clearProtocolVersion() → void
clearQuery() → void
clearRequestId() → void
clearSignAuthorityAttestation() → void
clearSignBirthCertificate() → void
clearSigningIdentity() → void
clearSignOfferPreparation() → void
clearSignPreparedOffer() → void
clearSync() → void
clearUnwrapScopeKey() → void
clearWrapScopeKey() → void
clone() → CallRequest
Creates a deep copy of the fields in this message.
copyWith(void updates(CallRequest)) → CallRequest
Apply updates to a copy of this message.
createEmptyInstance() → CallRequest
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureConfigure() → KernelConfigurationRequest
ensureCustody() → CustodyRequest
ensureEncryptionIdentity() → EncryptionIdentityRequest
ensureMintTypedId() → MintTypedIdRequest
ensureOffer() → OfferRequest
ensureOpen() → OpenRequest
ensureOutbox() → OutboxRequest
ensurePrepareRemoteOffer() → PrepareRemoteOfferRequest
ensureQuery() → QueryRequest
ensureSignAuthorityAttestation() → SignAuthorityAttestationRequest
ensureSignBirthCertificate() → SignBirthCertificateRequest
ensureSigningIdentity() → SigningIdentityRequest
ensureSignOfferPreparation() → SignOfferPreparationRequest
ensureSignPreparedOffer() → SignPreparedOfferRequest
ensureSync() → SyncRequest
ensureUnwrapScopeKey() → UnwrapScopeKeyRequest
ensureWrapScopeKey() → WrapScopeKeyRequest
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasConfigure() → bool
hasCustody() → bool
hasEncryptionIdentity() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasMintTypedId() → bool
hasOffer() → bool
hasOpen() → bool
hasOutbox() → bool
hasPrepareRemoteOffer() → bool
hasProtocolVersion() → bool
hasQuery() → bool
hasRequestId() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasSignAuthorityAttestation() → bool
hasSignBirthCertificate() → bool
hasSigningIdentity() → bool
hasSignOfferPreparation() → bool
hasSignPreparedOffer() → bool
hasSync() → bool
hasUnwrapScopeKey() → bool
hasWrapScopeKey() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichOperation() → CallRequest_Operation
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → CallRequest
getDefault() → CallRequest