KernelLawHydrationStep class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → KernelLawHydrationStep?
Constants
- KERNEL_LAW_HYDRATION_STEP_COMPOSE_STAGE → const KernelLawHydrationStep
- KERNEL_LAW_HYDRATION_STEP_DERIVE_SCHEMAS → const KernelLawHydrationStep
- KERNEL_LAW_HYDRATION_STEP_LOAD_POLICY_SHELL → const KernelLawHydrationStep
- KERNEL_LAW_HYDRATION_STEP_PACKAGE_COMPLETE → const KernelLawHydrationStep
- KERNEL_LAW_HYDRATION_STEP_READ_CLOSURE → const KernelLawHydrationStep
- KERNEL_LAW_HYDRATION_STEP_UNSPECIFIED → const KernelLawHydrationStep
-
values
→ const List<
KernelLawHydrationStep>