LiveLinkRole class
Which side of the live link a connection served.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → LiveLinkRole?
Constants
- LIVE_LINK_ROLE_PEER → const LiveLinkRole
- A replica following its upstream custodian.
- LIVE_LINK_ROLE_RELAY → const LiveLinkRole
- A hosted publisher relaying a custodian's frontier.
- LIVE_LINK_ROLE_UNSPECIFIED → const LiveLinkRole
-
values
→ const List<
LiveLinkRole>