QueryOperation class

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(int value) → QueryOperation?

Constants

QUERY_OPERATION_BIRTH_TRUST_STATE → const QueryOperation
QUERY_OPERATION_CANONICALIZE_FRONTIER → const QueryOperation
QUERY_OPERATION_CANONICALIZE_PROJECTION → const QueryOperation
QUERY_OPERATION_CERT_SIGN → const QueryOperation
QUERY_OPERATION_COUNTERFACTUAL → const QueryOperation
QUERY_OPERATION_CRYPTO_BLIND_INDEX_TOKEN → const QueryOperation
QUERY_OPERATION_CRYPTO_OWNED_DEVICE_REQUEST → const QueryOperation
QUERY_OPERATION_CRYPTO_OWNED_PREPARE_APPROVAL → const QueryOperation
QUERY_OPERATION_CRYPTO_OWNED_PREPARE_RECOVERY → const QueryOperation
QUERY_OPERATION_CRYPTO_OWNED_SCOPE_KEY → const QueryOperation
QUERY_OPERATION_CRYPTO_SEAL_FIELD → const QueryOperation
QUERY_OPERATION_CURRENT_LAW → const QueryOperation
QUERY_OPERATION_DECLARED_CAPABILITIES → const QueryOperation
QUERY_OPERATION_DELEGATION_CERT_SIGN → const QueryOperation
QUERY_OPERATION_DESCRIBE → const QueryOperation
QUERY_OPERATION_DEVELOPER_SPANS → const QueryOperation
QUERY_OPERATION_ERA_CERT_SIGN → const QueryOperation
QUERY_OPERATION_EXTREMUM → const QueryOperation
QUERY_OPERATION_INSTALLED_LAW → const QueryOperation
QUERY_OPERATION_INTERFACE_OFFER → const QueryOperation
QUERY_OPERATION_KERNEL_RESOURCE → const QueryOperation
QUERY_OPERATION_MEMORY_DROP_PROBE → const QueryOperation
QUERY_OPERATION_PROJECTION_STATS → const QueryOperation
QUERY_OPERATION_READ_POSTURE → const QueryOperation
QUERY_OPERATION_READINESS → const QueryOperation
QUERY_OPERATION_RECEIPT_PATH → const QueryOperation
QUERY_OPERATION_REFRESH → const QueryOperation
QUERY_OPERATION_RELATION_GATE_OFFER → const QueryOperation
QUERY_OPERATION_ROUTE → const QueryOperation
QUERY_OPERATION_SCENE_LAW → const QueryOperation
QUERY_OPERATION_UNSPECIFIED → const QueryOperation
QUERY_OPERATION_VERIFY_CHAIN → const QueryOperation
QUERY_OPERATION_WARM → const QueryOperation
values → const List<QueryOperation>