ReadMaintenanceCause class
Disposable acceleration is demand-driven by changes to verified custody. These causes explain why the Peer Office scheduled work; they never become application facts or authority.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → ReadMaintenanceCause?
Constants
- READ_MAINTENANCE_CAUSE_ADMITTED_OFFER → const ReadMaintenanceCause
- READ_MAINTENANCE_CAUSE_DOMAIN_PREPARATION → const ReadMaintenanceCause
- READ_MAINTENANCE_CAUSE_OPEN → const ReadMaintenanceCause
- READ_MAINTENANCE_CAUSE_READ_DEBT → const ReadMaintenanceCause
- READ_MAINTENANCE_CAUSE_RESIDENCY → const ReadMaintenanceCause
- Existing retained custody entered this Peer Runtime process and must regain its disposable serving indexes without waiting for interaction.
- READ_MAINTENANCE_CAUSE_SYNC → const ReadMaintenanceCause
- READ_MAINTENANCE_CAUSE_UNSPECIFIED → const ReadMaintenanceCause
-
values
→ const List<
ReadMaintenanceCause>