ReceivingGroupConvergenceOutcome class

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(int value) → ReceivingGroupConvergenceOutcome?

Constants

RECEIVING_GROUP_CONVERGENCE_OUTCOME_CONVERGED → const ReceivingGroupConvergenceOutcome
Terminal: the group is provably converged with its parent.
RECEIVING_GROUP_CONVERGENCE_OUTCOME_DEFERRED → const ReceivingGroupConvergenceOutcome
Terminal for this run: custody was good enough to open on, but the group is not yet provably converged; the tail runs again on the next open.
RECEIVING_GROUP_CONVERGENCE_OUTCOME_IN_PROGRESS → const ReceivingGroupConvergenceOutcome
Progress: the named phase is running.
RECEIVING_GROUP_CONVERGENCE_OUTCOME_UNSPECIFIED → const ReceivingGroupConvergenceOutcome
values → const List<ReceivingGroupConvergenceOutcome>