RuntimeEvent class

Available extensions

Constructors

RuntimeEvent({Int64? sequence, String? session, RuntimeReady? ready, WatchChanged? watchChanged, SyncCompleted? syncCompleted, LinkChanged? linkChanged, SignalChanged? signalChanged, CustodyChanged? custodyChanged, LocalWorkRejected? localWorkRejected, LawChanged? lawChanged, KernelProgressObserved? kernelProgress, RuntimeSpan? span, TransferProgress? transferProgress, ReadMaintenanceProgress? maintenanceProgress, PeerSocketEffect? socketEffect, CredentialRefreshRequested? credentialRefreshRequested, ReceivingGroupConvergence? receivingGroupConvergence, ModelAdoptionProgress? modelAdoptionProgress, FollowsSummary? followsSummary, PreservedLocalCopy? localCopyPreserved, ForeignPlacementIgnored? foreignPlacementIgnored, QuarantinedBinding? bindingQuarantined, WritePreparation? writePreparation, ReadAccessPreparation? readAccessPreparation})
factory
RuntimeEvent.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
RuntimeEvent.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

bindingQuarantined ↔ QuarantinedBinding
Application-wide diagnostic: a persisted binding another office created was quarantined.
getter/setter pair
credentialRefreshRequested ↔ CredentialRefreshRequested
getter/setter pair
custodyChanged ↔ CustodyChanged
getter/setter pair
followsSummary ↔ FollowsSummary
getter/setter pair
foreignPlacementIgnored ↔ ForeignPlacementIgnored
Application-wide diagnostic: a placement naming a non-configured origin was ignored.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
kernelProgress ↔ KernelProgressObserved
getter/setter pair
lawChanged ↔ LawChanged
getter/setter pair
linkChanged ↔ LinkChanged
getter/setter pair
localCopyPreserved ↔ PreservedLocalCopy
Application-wide diagnostic: a local copy was replaced by a refetch and preserved.
getter/setter pair
localWorkRejected ↔ LocalWorkRejected
getter/setter pair
maintenanceProgress ↔ ReadMaintenanceProgress
getter/setter pair
modelAdoptionProgress ↔ ModelAdoptionProgress
getter/setter pair
readAccessPreparation ↔ ReadAccessPreparation
getter/setter pair
ready ↔ RuntimeReady
getter/setter pair
receivingGroupConvergence ↔ ReceivingGroupConvergence
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence ↔ Int64
getter/setter pair
session ↔ String
getter/setter pair
signalChanged ↔ SignalChanged
getter/setter pair
socketEffect ↔ PeerSocketEffect
getter/setter pair
span ↔ RuntimeSpan
getter/setter pair
syncCompleted ↔ SyncCompleted
getter/setter pair
transferProgress ↔ TransferProgress
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
watchChanged ↔ WatchChanged
getter/setter pair
writePreparation ↔ WritePreparation
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBindingQuarantined() → void
clearCredentialRefreshRequested() → void
clearCustodyChanged() → void
clearEvent() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFollowsSummary() → void
clearForeignPlacementIgnored() → void
clearKernelProgress() → void
clearLawChanged() → void
clearLinkChanged() → void
clearLocalCopyPreserved() → void
clearLocalWorkRejected() → void
clearMaintenanceProgress() → void
clearModelAdoptionProgress() → void
clearReadAccessPreparation() → void
clearReady() → void
clearReceivingGroupConvergence() → void
clearSequence() → void
clearSession() → void
clearSignalChanged() → void
clearSocketEffect() → void
clearSpan() → void
clearSyncCompleted() → void
clearTransferProgress() → void
clearWatchChanged() → void
clearWritePreparation() → void
clone() → RuntimeEvent
Creates a deep copy of the fields in this message.
copyWith(void updates(RuntimeEvent)) → RuntimeEvent
Apply updates to a copy of this message.
createEmptyInstance() → RuntimeEvent
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureBindingQuarantined() → QuarantinedBinding
ensureCredentialRefreshRequested() → CredentialRefreshRequested
ensureCustodyChanged() → CustodyChanged
ensureFollowsSummary() → FollowsSummary
ensureForeignPlacementIgnored() → ForeignPlacementIgnored
ensureKernelProgress() → KernelProgressObserved
ensureLawChanged() → LawChanged
ensureLinkChanged() → LinkChanged
ensureLocalCopyPreserved() → PreservedLocalCopy
ensureLocalWorkRejected() → LocalWorkRejected
ensureMaintenanceProgress() → ReadMaintenanceProgress
ensureModelAdoptionProgress() → ModelAdoptionProgress
ensureReadAccessPreparation() → ReadAccessPreparation
ensureReady() → RuntimeReady
ensureReceivingGroupConvergence() → ReceivingGroupConvergence
ensureSignalChanged() → SignalChanged
ensureSocketEffect() → PeerSocketEffect
ensureSpan() → RuntimeSpan
ensureSyncCompleted() → SyncCompleted
ensureTransferProgress() → TransferProgress
ensureWatchChanged() → WatchChanged
ensureWritePreparation() → WritePreparation
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasBindingQuarantined() → bool
hasCredentialRefreshRequested() → bool
hasCustodyChanged() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasFollowsSummary() → bool
hasForeignPlacementIgnored() → bool
hasKernelProgress() → bool
hasLawChanged() → bool
hasLinkChanged() → bool
hasLocalCopyPreserved() → bool
hasLocalWorkRejected() → bool
hasMaintenanceProgress() → bool
hasModelAdoptionProgress() → bool
hasReadAccessPreparation() → bool
hasReady() → bool
hasReceivingGroupConvergence() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasSequence() → bool
hasSession() → bool
hasSignalChanged() → bool
hasSocketEffect() → bool
hasSpan() → bool
hasSyncCompleted() → bool
hasTransferProgress() → bool
hasWatchChanged() → bool
hasWritePreparation() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichEvent() → RuntimeEvent_Event
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → RuntimeEvent
getDefault() → RuntimeEvent