RuntimeOperation class

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) RuntimeOperation?

Constants

RUNTIME_OPERATION_ABSORB_SALVAGE → const RuntimeOperation
RUNTIME_OPERATION_ACTIVITY_LOG → const RuntimeOperation
RUNTIME_OPERATION_ADOPT_GENERATED_MODEL → const RuntimeOperation
RUNTIME_OPERATION_ASSERT_KERNEL_COHERENCE → const RuntimeOperation
RUNTIME_OPERATION_ATTESTATION_SIGN → const RuntimeOperation
RUNTIME_OPERATION_AUTHOR_KEYGEN → const RuntimeOperation
RUNTIME_OPERATION_AUTO_SYNC → const RuntimeOperation
RUNTIME_OPERATION_CAN_AUTHOR → const RuntimeOperation
RUNTIME_OPERATION_CERT_SIGN → const RuntimeOperation
RUNTIME_OPERATION_CHECK_COMPAT → const RuntimeOperation
RUNTIME_OPERATION_CHECK_COMPATIBILITY → const RuntimeOperation
RUNTIME_OPERATION_CHECK_REFERENCE_VERSIONS → const RuntimeOperation
RUNTIME_OPERATION_COMMITS → const RuntimeOperation
RUNTIME_OPERATION_COMPAT_HAS → const RuntimeOperation
RUNTIME_OPERATION_CONNECT → const RuntimeOperation
RUNTIME_OPERATION_CORRECT_MOST_RECENT → const RuntimeOperation
RUNTIME_OPERATION_COUNT → const RuntimeOperation
RUNTIME_OPERATION_COUNT_AT → const RuntimeOperation
RUNTIME_OPERATION_CREATE_WORKSPACE → const RuntimeOperation
RUNTIME_OPERATION_CRYPTO_KEYGEN → const RuntimeOperation
RUNTIME_OPERATION_CRYPTO_OWNED_BIRTH_SCOPE_KEY → const RuntimeOperation
RUNTIME_OPERATION_CRYPTO_OWNED_DEVICE_REQUEST → const RuntimeOperation
RUNTIME_OPERATION_CRYPTO_OWNED_ENSURE_IDENTITY → const RuntimeOperation
RUNTIME_OPERATION_CRYPTO_OWNED_PREPARE_APPROVAL → const RuntimeOperation
RUNTIME_OPERATION_CRYPTO_OWNED_PREPARE_RECORD_ACTION → const RuntimeOperation
RUNTIME_OPERATION_CRYPTO_OWNED_PROTECT_IDENTITY → const RuntimeOperation
RUNTIME_OPERATION_CRYPTO_OWNED_SCOPE_KEY → const RuntimeOperation
RUNTIME_OPERATION_CRYPTO_OWNED_SCOPE_KEYS → const RuntimeOperation
RUNTIME_OPERATION_CRYPTO_SEAL_FIELD → const RuntimeOperation
RUNTIME_OPERATION_CRYPTO_UNWRAP_KEY → const RuntimeOperation
RUNTIME_OPERATION_CRYPTO_WRAP_KEY → const RuntimeOperation
RUNTIME_OPERATION_CUSTODY_STATUS → const RuntimeOperation
RUNTIME_OPERATION_DEAD_LETTERS → const RuntimeOperation
RUNTIME_OPERATION_DEVICE_PUBLIC_OF → const RuntimeOperation
RUNTIME_OPERATION_DISCARD_DEAD_LETTER → const RuntimeOperation
RUNTIME_OPERATION_DISCARD_SALVAGED → const RuntimeOperation
RUNTIME_OPERATION_DISPOSE_REALM → const RuntimeOperation
RUNTIME_OPERATION_ENROLL_DEVICE → const RuntimeOperation
RUNTIME_OPERATION_ENSURE_PARENT_SIGNER_ENROLLMENT → const RuntimeOperation
RUNTIME_OPERATION_EXPORT → const RuntimeOperation
RUNTIME_OPERATION_HEAD → const RuntimeOperation
RUNTIME_OPERATION_HISTORY_OF → const RuntimeOperation
RUNTIME_OPERATION_INTERFACE_OFFER → const RuntimeOperation
RUNTIME_OPERATION_ISSUE_DELEGATION_CERT → const RuntimeOperation
RUNTIME_OPERATION_LAW_STATUS → const RuntimeOperation
RUNTIME_OPERATION_LIST_WORKSPACES → const RuntimeOperation
RUNTIME_OPERATION_MANIFESTS → const RuntimeOperation
RUNTIME_OPERATION_METRICS → const RuntimeOperation
RUNTIME_OPERATION_MINT_DELEGATION → const RuntimeOperation
RUNTIME_OPERATION_MINT_DEVICE_KEY → const RuntimeOperation
RUNTIME_OPERATION_MINT_ID → const RuntimeOperation
RUNTIME_OPERATION_MINT_KEYLESS_DELEGATION → const RuntimeOperation
RUNTIME_OPERATION_NOMOS_CHILD_WORKSPACES → const RuntimeOperation
RUNTIME_OPERATION_NOMOS_INTERNAL_BIRTH_RECEIVING_GROUP → const RuntimeOperation
RUNTIME_OPERATION_NOMOS_WORKSPACE_GENESIS → const RuntimeOperation
RUNTIME_OPERATION_OFFER → const RuntimeOperation
RUNTIME_OPERATION_OFFER_DIRECTIVE → const RuntimeOperation
RUNTIME_OPERATION_OFFER_INTENT → const RuntimeOperation
RUNTIME_OPERATION_PARENT_SIGNER_ENROLLMENT → const RuntimeOperation
RUNTIME_OPERATION_PENDING_CONFLICT_SUMMARY → const RuntimeOperation
RUNTIME_OPERATION_PENDING_CONFLICTS → const RuntimeOperation
RUNTIME_OPERATION_PREPARE_DOMAIN → const RuntimeOperation
RUNTIME_OPERATION_PULL → const RuntimeOperation
RUNTIME_OPERATION_QUERY → const RuntimeOperation
RUNTIME_OPERATION_QUERY_AT → const RuntimeOperation
RUNTIME_OPERATION_QUERY_BY_ID → const RuntimeOperation
RUNTIME_OPERATION_QUERY_BY_ID_AT → const RuntimeOperation
RUNTIME_OPERATION_QUERY_PAGE → const RuntimeOperation
RUNTIME_OPERATION_REDO_MOST_RECENT → const RuntimeOperation
RUNTIME_OPERATION_REFRESH_CREDENTIALS → const RuntimeOperation
RUNTIME_OPERATION_REOFFER_SALVAGED → const RuntimeOperation
RUNTIME_OPERATION_RESOLVE_CUSTODY_BREAK → const RuntimeOperation
RUNTIME_OPERATION_RESTORE_PREVIOUS_GENERATED_MODEL → const RuntimeOperation
RUNTIME_OPERATION_RETRY_DEAD_LETTER → const RuntimeOperation
RUNTIME_OPERATION_SALVAGE → const RuntimeOperation
RUNTIME_OPERATION_SALVAGED_INTENTS → const RuntimeOperation
RUNTIME_OPERATION_SHARE_WITH → const RuntimeOperation
RUNTIME_OPERATION_SIGN_BIRTH_CERT → const RuntimeOperation
RUNTIME_OPERATION_SNAPSHOT_WORKSPACE → const RuntimeOperation
RUNTIME_OPERATION_SPATIAL_WITHIN → const RuntimeOperation
RUNTIME_OPERATION_STAGE_GENERATED_MODEL → const RuntimeOperation
RUNTIME_OPERATION_STAGE_GENERATED_MODEL_FROM_PARENT → const RuntimeOperation
RUNTIME_OPERATION_STOP_AUTO_SYNC → const RuntimeOperation
RUNTIME_OPERATION_SUM → const RuntimeOperation
RUNTIME_OPERATION_SUM_AT → const RuntimeOperation
RUNTIME_OPERATION_SYNC → const RuntimeOperation
RUNTIME_OPERATION_SYNC_SIZE → const RuntimeOperation
RUNTIME_OPERATION_UNDO_MOST_RECENT → const RuntimeOperation
RUNTIME_OPERATION_UNSPECIFIED → const RuntimeOperation
RUNTIME_OPERATION_UNWATCH → const RuntimeOperation
RUNTIME_OPERATION_VERIFY_CHAIN → const RuntimeOperation
RUNTIME_OPERATION_WATCH → const RuntimeOperation
values → const List<RuntimeOperation>