RuntimeRequest class

Transitional numbered envelope at the peer office's front door. The actual papers are owned by the imported desk files; this file must not regain their fields or procedures. Tenant values remain canonical OpenUSD and never become an open protobuf map.

Available extensions

Constructors

RuntimeRequest({int? protocolVersion, Int64? requestId, TraceContext? trace, InvocationTarget? target, KernelCallRequest? kernelCall, ListWorkspacesRequest? listWorkspaces, SyncWorkspaceRequest? syncWorkspace, WatchRequest? watch, UnwatchRequest? unwatch, PrepareDomainRequest? prepareDomain, CloseRealmRequest? closeRealm, DeadLetterRequest? deadLetter, HistoricQueryRequest? historicQuery, WorkspaceStatusRequest? workspaceStatus, RemoteGeneratedOfferRequest? remoteGeneratedOffer, WorkspacePlacementRequest? workspacePlacement, RefreshCredentialsRequest? refreshCredentials, DeliverWorkspaceEffectsRequest? deliverWorkspaceEffects, AuthoringPreflightRequest? authoringPreflight, ListWorkspaceMomentsRequest? listWorkspaceMoments, EstimateWorkspaceTransferRequest? estimateWorkspaceTransfer, ReadWorkspaceGenesisRequest? readWorkspaceGenesis, ListChildWorkspacesRequest? listChildWorkspaces, FrameworkRequest? framework, ContinueCorrespondenceRequest? continueCorrespondence, IdentityProviderWitnessRequest? identityProviderWitness, MaintenanceTickRequest? maintenanceTick, ResidencyPressureRequest? residencyPressure, CustodyAdvancedRequest? custodyAdvanced, CustodyOfferBatchRequest? admitCustodyOffers, InspectLawPackageRequest? inspectLawPackage, ContinueLocalReadRequest? continueLocalRead, RetainFrontierRequest? retainFrontier, PeerSocketReceipt? socketReceipt, ExportLiveOffersRequest? exportLiveOffers, PrepareApplicationRequest? prepareApplication, AwaitAuthenticationRequest? awaitAuthentication, RecoverCorrespondenceRequest? recoverCorrespondence, OpenReceivingGroupRequest? openReceivingGroup, ConvergeReceivingGroupRequest? convergeReceivingGroup, AdoptApplicationModelRequest? adoptApplicationModel, ResolveWorkspaceNameRequest? resolveWorkspaceName, CheckReferenceVersionsRequest? checkReferenceVersions, DeliverHttpObligationRequest? deliverHttpObligation, RefreshReplicaCredentialRequest? refreshReplicaCredential, BindSessionRequest? bindSession, PreviewLocalCopyDropRequest? previewLocalCopyDrop, DropLocalCopyRequest? dropLocalCopy, ConfigureProviderOriginsRequest? configureProviderOrigins, FetchWorkspaceRequest? fetchWorkspace, ProvideLawProductsRequest? provideLawProducts})
factory
RuntimeRequest.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
RuntimeRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

admitCustodyOffers ↔ CustodyOfferBatchRequest
getter/setter pair
adoptApplicationModel ↔ AdoptApplicationModelRequest
getter/setter pair
authoringPreflight ↔ AuthoringPreflightRequest
getter/setter pair
awaitAuthentication ↔ AwaitAuthenticationRequest
getter/setter pair
bindSession ↔ BindSessionRequest
getter/setter pair
checkReferenceVersions ↔ CheckReferenceVersionsRequest
getter/setter pair
closeRealm ↔ CloseRealmRequest
getter/setter pair
configureProviderOrigins ↔ ConfigureProviderOriginsRequest
getter/setter pair
continueCorrespondence ↔ ContinueCorrespondenceRequest
getter/setter pair
continueLocalRead ↔ ContinueLocalReadRequest
getter/setter pair
convergeReceivingGroup ↔ ConvergeReceivingGroupRequest
getter/setter pair
custodyAdvanced ↔ CustodyAdvancedRequest
getter/setter pair
deadLetter ↔ DeadLetterRequest
getter/setter pair
deliverHttpObligation ↔ DeliverHttpObligationRequest
getter/setter pair
deliverWorkspaceEffects ↔ DeliverWorkspaceEffectsRequest
getter/setter pair
dropLocalCopy ↔ DropLocalCopyRequest
getter/setter pair
estimateWorkspaceTransfer ↔ EstimateWorkspaceTransferRequest
getter/setter pair
exportLiveOffers ↔ ExportLiveOffersRequest
getter/setter pair
fetchWorkspace ↔ FetchWorkspaceRequest
getter/setter pair
framework ↔ FrameworkRequest
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
historicQuery ↔ HistoricQueryRequest
getter/setter pair
identityProviderWitness ↔ IdentityProviderWitnessRequest
getter/setter pair
info_ → BuilderInfo
no setter
inspectLawPackage ↔ InspectLawPackageRequest
getter/setter pair
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
kernelCall ↔ KernelCallRequest
getter/setter pair
listChildWorkspaces ↔ ListChildWorkspacesRequest
getter/setter pair
listWorkspaceMoments ↔ ListWorkspaceMomentsRequest
getter/setter pair
listWorkspaces ↔ ListWorkspacesRequest
getter/setter pair
maintenanceTick ↔ MaintenanceTickRequest
getter/setter pair
openReceivingGroup ↔ OpenReceivingGroupRequest
getter/setter pair
prepareApplication ↔ PrepareApplicationRequest
getter/setter pair
prepareDomain ↔ PrepareDomainRequest
getter/setter pair
previewLocalCopyDrop ↔ PreviewLocalCopyDropRequest
getter/setter pair
protocolVersion ↔ int
getter/setter pair
provideLawProducts ↔ ProvideLawProductsRequest
getter/setter pair
readWorkspaceGenesis ↔ ReadWorkspaceGenesisRequest
getter/setter pair
recoverCorrespondence ↔ RecoverCorrespondenceRequest
getter/setter pair
refreshCredentials ↔ RefreshCredentialsRequest
getter/setter pair
refreshReplicaCredential ↔ RefreshReplicaCredentialRequest
getter/setter pair
remoteGeneratedOffer ↔ RemoteGeneratedOfferRequest
getter/setter pair
requestId ↔ Int64
getter/setter pair
residencyPressure ↔ ResidencyPressureRequest
getter/setter pair
resolveWorkspaceName ↔ ResolveWorkspaceNameRequest
getter/setter pair
retainFrontier ↔ RetainFrontierRequest
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socketReceipt ↔ PeerSocketReceipt
getter/setter pair
syncWorkspace ↔ SyncWorkspaceRequest
getter/setter pair
target ↔ InvocationTarget
The peer-office address for a frame arriving without a prior local session handshake. It is part of the typed paper, so every platform shell can pass the same bytes without decoding the command or inventing its own session lifecycle.
getter/setter pair
trace ↔ TraceContext
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
unwatch ↔ UnwatchRequest
getter/setter pair
watch ↔ WatchRequest
getter/setter pair
workspacePlacement ↔ WorkspacePlacementRequest
getter/setter pair
workspaceStatus ↔ WorkspaceStatusRequest
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAdmitCustodyOffers() → void
clearAdoptApplicationModel() → void
clearAuthoringPreflight() → void
clearAwaitAuthentication() → void
clearBindSession() → void
clearCheckReferenceVersions() → void
clearCloseRealm() → void
clearCommand() → void
clearConfigureProviderOrigins() → void
clearContinueCorrespondence() → void
clearContinueLocalRead() → void
clearConvergeReceivingGroup() → void
clearCustodyAdvanced() → void
clearDeadLetter() → void
clearDeliverHttpObligation() → void
clearDeliverWorkspaceEffects() → void
clearDropLocalCopy() → void
clearEstimateWorkspaceTransfer() → void
clearExportLiveOffers() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearFetchWorkspace() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFramework() → void
clearHistoricQuery() → void
clearIdentityProviderWitness() → void
clearInspectLawPackage() → void
clearKernelCall() → void
clearListChildWorkspaces() → void
clearListWorkspaceMoments() → void
clearListWorkspaces() → void
clearMaintenanceTick() → void
clearOpenReceivingGroup() → void
clearPrepareApplication() → void
clearPrepareDomain() → void
clearPreviewLocalCopyDrop() → void
clearProtocolVersion() → void
clearProvideLawProducts() → void
clearReadWorkspaceGenesis() → void
clearRecoverCorrespondence() → void
clearRefreshCredentials() → void
clearRefreshReplicaCredential() → void
clearRemoteGeneratedOffer() → void
clearRequestId() → void
clearResidencyPressure() → void
clearResolveWorkspaceName() → void
clearRetainFrontier() → void
clearSocketReceipt() → void
clearSyncWorkspace() → void
clearTarget() → void
clearTrace() → void
clearUnwatch() → void
clearWatch() → void
clearWorkspacePlacement() → void
clearWorkspaceStatus() → void
clone() → RuntimeRequest
Creates a deep copy of the fields in this message.
copyWith(void updates(RuntimeRequest)) → RuntimeRequest
Apply updates to a copy of this message.
createEmptyInstance() → RuntimeRequest
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureAdmitCustodyOffers() → CustodyOfferBatchRequest
ensureAdoptApplicationModel() → AdoptApplicationModelRequest
ensureAuthoringPreflight() → AuthoringPreflightRequest
ensureAwaitAuthentication() → AwaitAuthenticationRequest
ensureBindSession() → BindSessionRequest
ensureCheckReferenceVersions() → CheckReferenceVersionsRequest
ensureCloseRealm() → CloseRealmRequest
ensureConfigureProviderOrigins() → ConfigureProviderOriginsRequest
ensureContinueCorrespondence() → ContinueCorrespondenceRequest
ensureContinueLocalRead() → ContinueLocalReadRequest
ensureConvergeReceivingGroup() → ConvergeReceivingGroupRequest
ensureCustodyAdvanced() → CustodyAdvancedRequest
ensureDeadLetter() → DeadLetterRequest
ensureDeliverHttpObligation() → DeliverHttpObligationRequest
ensureDeliverWorkspaceEffects() → DeliverWorkspaceEffectsRequest
ensureDropLocalCopy() → DropLocalCopyRequest
ensureEstimateWorkspaceTransfer() → EstimateWorkspaceTransferRequest
ensureExportLiveOffers() → ExportLiveOffersRequest
ensureFetchWorkspace() → FetchWorkspaceRequest
ensureFramework() → FrameworkRequest
ensureHistoricQuery() → HistoricQueryRequest
ensureIdentityProviderWitness() → IdentityProviderWitnessRequest
ensureInspectLawPackage() → InspectLawPackageRequest
ensureKernelCall() → KernelCallRequest
ensureListChildWorkspaces() → ListChildWorkspacesRequest
ensureListWorkspaceMoments() → ListWorkspaceMomentsRequest
ensureListWorkspaces() → ListWorkspacesRequest
ensureMaintenanceTick() → MaintenanceTickRequest
ensureOpenReceivingGroup() → OpenReceivingGroupRequest
ensurePrepareApplication() → PrepareApplicationRequest
ensurePrepareDomain() → PrepareDomainRequest
ensurePreviewLocalCopyDrop() → PreviewLocalCopyDropRequest
ensureProvideLawProducts() → ProvideLawProductsRequest
ensureReadWorkspaceGenesis() → ReadWorkspaceGenesisRequest
ensureRecoverCorrespondence() → RecoverCorrespondenceRequest
ensureRefreshCredentials() → RefreshCredentialsRequest
ensureRefreshReplicaCredential() → RefreshReplicaCredentialRequest
ensureRemoteGeneratedOffer() → RemoteGeneratedOfferRequest
ensureResidencyPressure() → ResidencyPressureRequest
ensureResolveWorkspaceName() → ResolveWorkspaceNameRequest
ensureRetainFrontier() → RetainFrontierRequest
ensureSocketReceipt() → PeerSocketReceipt
ensureSyncWorkspace() → SyncWorkspaceRequest
ensureTarget() → InvocationTarget
ensureTrace() → TraceContext
ensureUnwatch() → UnwatchRequest
ensureWatch() → WatchRequest
ensureWorkspacePlacement() → WorkspacePlacementRequest
ensureWorkspaceStatus() → WorkspaceStatusRequest
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasAdmitCustodyOffers() → bool
hasAdoptApplicationModel() → bool
hasAuthoringPreflight() → bool
hasAwaitAuthentication() → bool
hasBindSession() → bool
hasCheckReferenceVersions() → bool
hasCloseRealm() → bool
hasConfigureProviderOrigins() → bool
hasContinueCorrespondence() → bool
hasContinueLocalRead() → bool
hasConvergeReceivingGroup() → bool
hasCustodyAdvanced() → bool
hasDeadLetter() → bool
hasDeliverHttpObligation() → bool
hasDeliverWorkspaceEffects() → bool
hasDropLocalCopy() → bool
hasEstimateWorkspaceTransfer() → bool
hasExportLiveOffers() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasFetchWorkspace() → bool
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasFramework() → bool
hasHistoricQuery() → bool
hasIdentityProviderWitness() → bool
hasInspectLawPackage() → bool
hasKernelCall() → bool
hasListChildWorkspaces() → bool
hasListWorkspaceMoments() → bool
hasListWorkspaces() → bool
hasMaintenanceTick() → bool
hasOpenReceivingGroup() → bool
hasPrepareApplication() → bool
hasPrepareDomain() → bool
hasPreviewLocalCopyDrop() → bool
hasProtocolVersion() → bool
hasProvideLawProducts() → bool
hasReadWorkspaceGenesis() → bool
hasRecoverCorrespondence() → bool
hasRefreshCredentials() → bool
hasRefreshReplicaCredential() → bool
hasRemoteGeneratedOffer() → bool
hasRequestId() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasResidencyPressure() → bool
hasResolveWorkspaceName() → bool
hasRetainFrontier() → bool
hasSocketReceipt() → bool
hasSyncWorkspace() → bool
hasTarget() → bool
hasTrace() → bool
hasUnwatch() → bool
hasWatch() → bool
hasWorkspacePlacement() → bool
hasWorkspaceStatus() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichCommand() → RuntimeRequest_Command
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → RuntimeRequest
getDefault() → RuntimeRequest