CustodyRequest class
- Available extensions
Constructors
- CustodyRequest({PackDeltaRequest? packDelta, ApplyPackRequest? applyPack, RepoStatsRequest? repoStats, IntentsAboveRequest? intentsAbove, InspectChangeRequest? inspectChange, EncodeRefusalVerdictRequest? encodeRefusalVerdict, InspectRefusalVerdictRequest? inspectRefusalVerdict, ReadBlobRequest? readBlob, ResolveRefRequest? resolveRef, ListRefsRequest? listRefs, WriteRefRequest? writeRef, DeleteRefRequest? deleteRef, WriteMetaCommitRequest? writeMetaCommit, LawClosureInfoRequest? lawClosureInfo, CheckpointExportRequest? checkpointExport, CheckpointImportRequest? checkpointImport, CapacityReserveRequest? capacityReserve, RestoreMainRequest? restoreMain, ResolveStatePositionRequest? resolveStatePosition, ResidentFootprintRequest? residentFootprint, HistorySummaryRequest? historySummary, ProveCompactionEquivalenceRequest? proveCompactionEquivalence})
-
factory
-
CustodyRequest.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- CustodyRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- applyPack ↔ ApplyPackRequest
-
getter/setter pair
- capacityReserve ↔ CapacityReserveRequest
-
getter/setter pair
- checkpointExport ↔ CheckpointExportRequest
-
getter/setter pair
- checkpointImport ↔ CheckpointImportRequest
-
getter/setter pair
- deleteRef ↔ DeleteRefRequest
-
getter/setter pair
- encodeRefusalVerdict ↔ EncodeRefusalVerdictRequest
-
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- historySummary ↔ HistorySummaryRequest
-
getter/setter pair
- info_ → BuilderInfo
-
no setter
- inspectChange ↔ InspectChangeRequest
-
getter/setter pair
- inspectRefusalVerdict ↔ InspectRefusalVerdictRequest
-
getter/setter pair
- intentsAbove ↔ IntentsAboveRequest
-
getter/setter pair
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - lawClosureInfo ↔ LawClosureInfoRequest
-
getter/setter pair
- listRefs ↔ ListRefsRequest
-
getter/setter pair
- packDelta ↔ PackDeltaRequest
-
getter/setter pair
- proveCompactionEquivalence ↔ ProveCompactionEquivalenceRequest
-
getter/setter pair
- readBlob ↔ ReadBlobRequest
-
getter/setter pair
- repoStats ↔ RepoStatsRequest
-
getter/setter pair
- residentFootprint ↔ ResidentFootprintRequest
-
getter/setter pair
- resolveRef ↔ ResolveRefRequest
-
getter/setter pair
- resolveStatePosition ↔ ResolveStatePositionRequest
-
getter/setter pair
- restoreMain ↔ RestoreMainRequest
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unknownFields → UnknownFieldSet
-
no setterinherited
- writeMetaCommit ↔ WriteMetaCommitRequest
-
getter/setter pair
- writeRef ↔ WriteRefRequest
-
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearApplyPack(
) → void -
clearCapacityReserve(
) → void -
clearCheckpointExport(
) → void -
clearCheckpointImport(
) → void -
clearDeleteRef(
) → void -
clearEncodeRefusalVerdict(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearHistorySummary(
) → void -
clearInspectChange(
) → void -
clearInspectRefusalVerdict(
) → void -
clearIntentsAbove(
) → void -
clearLawClosureInfo(
) → void -
clearListRefs(
) → void -
clearOperation(
) → void -
clearPackDelta(
) → void -
clearProveCompactionEquivalence(
) → void -
clearReadBlob(
) → void -
clearRepoStats(
) → void -
clearResidentFootprint(
) → void -
clearResolveRef(
) → void -
clearResolveStatePosition(
) → void -
clearRestoreMain(
) → void -
clearWriteMetaCommit(
) → void -
clearWriteRef(
) → void -
clone(
) → CustodyRequest - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(CustodyRequest)) → CustodyRequest -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → CustodyRequest - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureApplyPack(
) → ApplyPackRequest -
ensureCapacityReserve(
) → CapacityReserveRequest -
ensureCheckpointExport(
) → CheckpointExportRequest -
ensureCheckpointImport(
) → CheckpointImportRequest -
ensureDeleteRef(
) → DeleteRefRequest -
ensureEncodeRefusalVerdict(
) → EncodeRefusalVerdictRequest -
ensureHistorySummary(
) → HistorySummaryRequest -
ensureInspectChange(
) → InspectChangeRequest -
ensureInspectRefusalVerdict(
) → InspectRefusalVerdictRequest -
ensureIntentsAbove(
) → IntentsAboveRequest -
ensureLawClosureInfo(
) → LawClosureInfoRequest -
ensureListRefs(
) → ListRefsRequest -
ensurePackDelta(
) → PackDeltaRequest -
ensureProveCompactionEquivalence(
) → ProveCompactionEquivalenceRequest -
ensureReadBlob(
) → ReadBlobRequest -
ensureRepoStats(
) → RepoStatsRequest -
ensureResidentFootprint(
) → ResidentFootprintRequest -
ensureResolveRef(
) → ResolveRefRequest -
ensureResolveStatePosition(
) → ResolveStatePositionRequest -
ensureRestoreMain(
) → RestoreMainRequest -
ensureWriteMetaCommit(
) → WriteMetaCommitRequest -
ensureWriteRef(
) → WriteRefRequest -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasApplyPack(
) → bool -
hasCapacityReserve(
) → bool -
hasCheckpointExport(
) → bool -
hasCheckpointImport(
) → bool -
hasDeleteRef(
) → bool -
hasEncodeRefusalVerdict(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasHistorySummary(
) → bool -
hasInspectChange(
) → bool -
hasInspectRefusalVerdict(
) → bool -
hasIntentsAbove(
) → bool -
hasLawClosureInfo(
) → bool -
hasListRefs(
) → bool -
hasPackDelta(
) → bool -
hasProveCompactionEquivalence(
) → bool -
hasReadBlob(
) → bool -
hasRepoStats(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasResidentFootprint(
) → bool -
hasResolveRef(
) → bool -
hasResolveStatePosition(
) → bool -
hasRestoreMain(
) → bool -
hasWriteMetaCommit(
) → bool -
hasWriteRef(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
whichOperation(
) → CustodyRequest_Operation -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → CustodyRequest -
getDefault(
) → CustodyRequest