CustodyResponse class

Available extensions

Constructors

CustodyResponse({PackDeltaResponse? packDelta, ApplyPackResponse? applyPack, RepoStatsResponse? repoStats, IntentsAboveResponse? intentsAbove, InspectChangeResponse? inspectChange, EncodeRefusalVerdictResponse? encodeRefusalVerdict, InspectRefusalVerdictResponse? inspectRefusalVerdict, ReadBlobResponse? readBlob, ResolveRefResponse? resolveRef, ListRefsResponse? listRefs, Acknowledged? writeRef, Acknowledged? deleteRef, WriteMetaCommitResponse? writeMetaCommit, LawClosureInfoResponse? lawClosureInfo, CheckpointExportResponse? checkpointExport, CheckpointImportResponse? checkpointImport, CapacityReserveResponse? capacityReserve, RestoreMainResponse? restoreMain, ResolveStatePositionResponse? resolveStatePosition, ResidentFootprintResponse? residentFootprint, HistorySummaryResponse? historySummary, ProveCompactionEquivalenceResponse? proveCompactionEquivalence})
factory
CustodyResponse.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
CustodyResponse.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

applyPack ApplyPackResponse
getter/setter pair
capacityReserve CapacityReserveResponse
getter/setter pair
checkpointExport CheckpointExportResponse
getter/setter pair
checkpointImport CheckpointImportResponse
getter/setter pair
deleteRef Acknowledged
getter/setter pair
encodeRefusalVerdict EncodeRefusalVerdictResponse
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
historySummary HistorySummaryResponse
getter/setter pair
info_ → BuilderInfo
no setter
inspectChange InspectChangeResponse
getter/setter pair
inspectRefusalVerdict InspectRefusalVerdictResponse
getter/setter pair
intentsAbove IntentsAboveResponse
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
lawClosureInfo LawClosureInfoResponse
getter/setter pair
listRefs ListRefsResponse
getter/setter pair
packDelta PackDeltaResponse
getter/setter pair
proveCompactionEquivalence ProveCompactionEquivalenceResponse
getter/setter pair
readBlob ReadBlobResponse
getter/setter pair
repoStats RepoStatsResponse
getter/setter pair
residentFootprint ResidentFootprintResponse
getter/setter pair
resolveRef ResolveRefResponse
getter/setter pair
resolveStatePosition ResolveStatePositionResponse
getter/setter pair
restoreMain RestoreMainResponse
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unknownFields → UnknownFieldSet
no setterinherited
writeMetaCommit WriteMetaCommitResponse
getter/setter pair
writeRef Acknowledged
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearApplyPack() → void
clearCapacityReserve() → void
clearCheckpointExport() → void
clearCheckpointImport() → void
clearDeleteRef() → void
clearEncodeRefusalVerdict() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearHistorySummary() → void
clearInspectChange() → void
clearInspectRefusalVerdict() → void
clearIntentsAbove() → void
clearLawClosureInfo() → void
clearListRefs() → void
clearOperation() → void
clearPackDelta() → void
clearProveCompactionEquivalence() → void
clearReadBlob() → void
clearRepoStats() → void
clearResidentFootprint() → void
clearResolveRef() → void
clearResolveStatePosition() → void
clearRestoreMain() → void
clearWriteMetaCommit() → void
clearWriteRef() → void
clone() CustodyResponse
Creates a deep copy of the fields in this message.
copyWith(void updates(CustodyResponse)) CustodyResponse
Apply updates to a copy of this message.
createEmptyInstance() CustodyResponse
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureApplyPack() ApplyPackResponse
ensureCapacityReserve() CapacityReserveResponse
ensureCheckpointExport() CheckpointExportResponse
ensureCheckpointImport() CheckpointImportResponse
ensureDeleteRef() Acknowledged
ensureEncodeRefusalVerdict() EncodeRefusalVerdictResponse
ensureHistorySummary() HistorySummaryResponse
ensureInspectChange() InspectChangeResponse
ensureInspectRefusalVerdict() InspectRefusalVerdictResponse
ensureIntentsAbove() IntentsAboveResponse
ensureLawClosureInfo() LawClosureInfoResponse
ensureListRefs() ListRefsResponse
ensurePackDelta() PackDeltaResponse
ensureProveCompactionEquivalence() ProveCompactionEquivalenceResponse
ensureReadBlob() ReadBlobResponse
ensureRepoStats() RepoStatsResponse
ensureResidentFootprint() ResidentFootprintResponse
ensureResolveRef() ResolveRefResponse
ensureResolveStatePosition() ResolveStatePositionResponse
ensureRestoreMain() RestoreMainResponse
ensureWriteMetaCommit() WriteMetaCommitResponse
ensureWriteRef() Acknowledged
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasApplyPack() bool
hasCapacityReserve() bool
hasCheckpointExport() bool
hasCheckpointImport() bool
hasDeleteRef() bool
hasEncodeRefusalVerdict() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasHistorySummary() bool
hasInspectChange() bool
hasInspectRefusalVerdict() bool
hasIntentsAbove() bool
hasLawClosureInfo() bool
hasListRefs() bool
hasPackDelta() bool
hasProveCompactionEquivalence() bool
hasReadBlob() bool
hasRepoStats() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasResidentFootprint() bool
hasResolveRef() bool
hasResolveStatePosition() bool
hasRestoreMain() bool
hasWriteMetaCommit() bool
hasWriteRef() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
whichOperation() CustodyResponse_Operation
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() CustodyResponse
getDefault() CustodyResponse