QueryRequest class

Available extensions

Constructors

QueryRequest({WorkspaceTarget? target, QueryAuthority? authority, bool? spans, QueryResultFormat? resultFormat, RowsQuery? rows, PageQuery? page, ByIdQuery? byId, ResolveRefsQuery? resolveRefs, ReferenceVersionsQuery? referenceVersions, TallyQuery? count, TallyQuery? sum, SpatialQuery? spatial, NamedQuery? named, AuthorizationCheckRequest? authorizationCheck, AuthorizationExpandRequest? authorizationExpand, FrontierTransitionRequest? frontierTransition, ByTypeQuery? byType, OwnedDeviceRequestQuery? ownedDeviceRequest, OwnedPrepareApprovalQuery? ownedPrepareApproval, PendingConflictsQuery? pendingConflicts, PendingConflictSummaryQuery? pendingConflictSummary, AuthenticationPostureQuery? authenticationPosture})
factory
QueryRequest.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
QueryRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

authenticationPosture AuthenticationPostureQuery
getter/setter pair
authority QueryAuthority
getter/setter pair
authorizationCheck AuthorizationCheckRequest
getter/setter pair
authorizationExpand AuthorizationExpandRequest
getter/setter pair
byId ByIdQuery
getter/setter pair
byType ByTypeQuery
getter/setter pair
count TallyQuery
getter/setter pair
frontierTransition FrontierTransitionRequest
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
named NamedQuery
getter/setter pair
ownedDeviceRequest OwnedDeviceRequestQuery
getter/setter pair
ownedPrepareApproval OwnedPrepareApprovalQuery
getter/setter pair
page PageQuery
getter/setter pair
pendingConflicts PendingConflictsQuery
getter/setter pair
pendingConflictSummary PendingConflictSummaryQuery
getter/setter pair
referenceVersions ReferenceVersionsQuery
getter/setter pair
resolveRefs ResolveRefsQuery
getter/setter pair
resultFormat QueryResultFormat
getter/setter pair
rows RowsQuery
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spans bool
getter/setter pair
spatial SpatialQuery
getter/setter pair
sum TallyQuery
getter/setter pair
target WorkspaceTarget
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAuthenticationPosture() → void
clearAuthority() → void
clearAuthorizationCheck() → void
clearAuthorizationExpand() → void
clearById() → void
clearByType() → void
clearCount() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFrontierTransition() → void
clearNamed() → void
clearOwnedDeviceRequest() → void
clearOwnedPrepareApproval() → void
clearPage() → void
clearPendingConflicts() → void
clearPendingConflictSummary() → void
clearQuery() → void
clearReferenceVersions() → void
clearResolveRefs() → void
clearResultFormat() → void
clearRows() → void
clearSpans() → void
clearSpatial() → void
clearSum() → void
clearTarget() → void
clone() QueryRequest
Creates a deep copy of the fields in this message.
copyWith(void updates(QueryRequest)) QueryRequest
Apply updates to a copy of this message.
createEmptyInstance() QueryRequest
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureAuthenticationPosture() AuthenticationPostureQuery
ensureAuthority() QueryAuthority
ensureAuthorizationCheck() AuthorizationCheckRequest
ensureAuthorizationExpand() AuthorizationExpandRequest
ensureById() ByIdQuery
ensureByType() ByTypeQuery
ensureCount() TallyQuery
ensureFrontierTransition() FrontierTransitionRequest
ensureNamed() NamedQuery
ensureOwnedDeviceRequest() OwnedDeviceRequestQuery
ensureOwnedPrepareApproval() OwnedPrepareApprovalQuery
ensurePage() PageQuery
ensurePendingConflicts() PendingConflictsQuery
ensurePendingConflictSummary() PendingConflictSummaryQuery
ensureReferenceVersions() ReferenceVersionsQuery
ensureResolveRefs() ResolveRefsQuery
ensureRows() RowsQuery
ensureSpatial() SpatialQuery
ensureSum() TallyQuery
ensureTarget() WorkspaceTarget
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAuthenticationPosture() bool
hasAuthority() bool
hasAuthorizationCheck() bool
hasAuthorizationExpand() bool
hasById() bool
hasByType() bool
hasCount() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFrontierTransition() bool
hasNamed() bool
hasOwnedDeviceRequest() bool
hasOwnedPrepareApproval() bool
hasPage() bool
hasPendingConflicts() bool
hasPendingConflictSummary() bool
hasReferenceVersions() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasResolveRefs() bool
hasResultFormat() bool
hasRows() bool
hasSpans() bool
hasSpatial() bool
hasSum() bool
hasTarget() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
whichQuery() QueryRequest_Query
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() QueryRequest
getDefault() QueryRequest