RuntimeRequest class
- Available extensions
Constructors
- RuntimeRequest({int? protocolVersion, Int64? requestId, TraceContext? trace, KernelCallRequest? kernelCall, ConnectRequest? connect, ListWorkspacesRequest? listWorkspaces, SnapshotWorkspaceRequest? snapshotWorkspace, SyncWorkspaceRequest? syncWorkspace, StartAutoSyncRequest? startAutoSync, StopAutoSyncRequest? stopAutoSync, WatchRequest? watch, UnwatchRequest? unwatch, PrepareDomainRequest? prepareDomain, ResolveCustodyBreakRequest? resolveCustodyBreak, CloseRealmRequest? closeRealm, DeadLetterRequest? deadLetter, HistoricQueryRequest? historicQuery, ModelLifecycleRequest? modelLifecycle, EstablishApplicationCustodyRequest? establishApplicationCustody})
-
factory
-
RuntimeRequest.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- RuntimeRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- closeRealm ↔ CloseRealmRequest
-
getter/setter pair
- connect ↔ ConnectRequest
-
getter/setter pair
- deadLetter ↔ DeadLetterRequest
-
getter/setter pair
- establishApplicationCustody ↔ EstablishApplicationCustodyRequest
-
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- historicQuery ↔ HistoricQueryRequest
-
getter/setter pair
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - kernelCall ↔ KernelCallRequest
-
getter/setter pair
- listWorkspaces ↔ ListWorkspacesRequest
-
getter/setter pair
- modelLifecycle ↔ ModelLifecycleRequest
-
getter/setter pair
- prepareDomain ↔ PrepareDomainRequest
-
getter/setter pair
- protocolVersion ↔ int
-
getter/setter pair
- requestId ↔ Int64
-
getter/setter pair
- resolveCustodyBreak ↔ ResolveCustodyBreakRequest
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshotWorkspace ↔ SnapshotWorkspaceRequest
-
getter/setter pair
- startAutoSync ↔ StartAutoSyncRequest
-
getter/setter pair
- stopAutoSync ↔ StopAutoSyncRequest
-
getter/setter pair
- syncWorkspace ↔ SyncWorkspaceRequest
-
getter/setter pair
- trace ↔ TraceContext
-
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- unwatch ↔ UnwatchRequest
-
getter/setter pair
- watch ↔ WatchRequest
-
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearCloseRealm(
) → void -
clearCommand(
) → void -
clearConnect(
) → void -
clearDeadLetter(
) → void -
clearEstablishApplicationCustody(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearHistoricQuery(
) → void -
clearKernelCall(
) → void -
clearListWorkspaces(
) → void -
clearModelLifecycle(
) → void -
clearPrepareDomain(
) → void -
clearProtocolVersion(
) → void -
clearRequestId(
) → void -
clearResolveCustodyBreak(
) → void -
clearSnapshotWorkspace(
) → void -
clearStartAutoSync(
) → void -
clearStopAutoSync(
) → void -
clearSyncWorkspace(
) → void -
clearTrace(
) → void -
clearUnwatch(
) → void -
clearWatch(
) → void -
clone(
) → RuntimeRequest - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(RuntimeRequest)) → RuntimeRequest -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → RuntimeRequest - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureCloseRealm(
) → CloseRealmRequest -
ensureConnect(
) → ConnectRequest -
ensureDeadLetter(
) → DeadLetterRequest -
ensureEstablishApplicationCustody(
) → EstablishApplicationCustodyRequest -
ensureHistoricQuery(
) → HistoricQueryRequest -
ensureKernelCall(
) → KernelCallRequest -
ensureListWorkspaces(
) → ListWorkspacesRequest -
ensureModelLifecycle(
) → ModelLifecycleRequest -
ensurePrepareDomain(
) → PrepareDomainRequest -
ensureResolveCustodyBreak(
) → ResolveCustodyBreakRequest -
ensureSnapshotWorkspace(
) → SnapshotWorkspaceRequest -
ensureStartAutoSync(
) → StartAutoSyncRequest -
ensureStopAutoSync(
) → StopAutoSyncRequest -
ensureSyncWorkspace(
) → SyncWorkspaceRequest -
ensureTrace(
) → TraceContext -
ensureUnwatch(
) → UnwatchRequest -
ensureWatch(
) → WatchRequest -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasCloseRealm(
) → bool -
hasConnect(
) → bool -
hasDeadLetter(
) → bool -
hasEstablishApplicationCustody(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasHistoricQuery(
) → bool -
hasKernelCall(
) → bool -
hasListWorkspaces(
) → bool -
hasModelLifecycle(
) → bool -
hasPrepareDomain(
) → bool -
hasProtocolVersion(
) → bool -
hasRequestId(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasResolveCustodyBreak(
) → bool -
hasSnapshotWorkspace(
) → bool -
hasStartAutoSync(
) → bool -
hasStopAutoSync(
) → bool -
hasSyncWorkspace(
) → bool -
hasTrace(
) → bool -
hasUnwatch(
) → bool -
hasWatch(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
whichCommand(
) → RuntimeRequest_Command -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → RuntimeRequest -
getDefault(
) → RuntimeRequest