RuntimeResponse class
- Available extensions
Constructors
- RuntimeResponse({int? protocolVersion, Int64? requestId, RuntimeFailure? failure, CallResponse? kernelCall, WorkspaceList? workspaceList, SyncWorkspaceResponse? syncWorkspace, WatchStarted? watchStarted, WatchStopped? watchStopped, DomainPrepared? domainPrepared, RealmClosed? realmClosed, RuntimeBlocked? blocked, RemoteOfferAdmission? remoteOfferAdmission, DeadLetterResponse? deadLetter, WorkspaceStatus? workspaceStatus, RemoteGeneratedOfferAccepted? remoteGeneratedOffer, WorkspacePlacementState? workspacePlacement, CredentialsRefreshed? credentialsRefreshed, WorkspaceEffectsDelivered? workspaceEffectsDelivered, AuthoringPreflightResult? authoringPreflight, WorkspaceMomentList? workspaceMoments, WorkspaceTransferEstimate? workspaceTransferEstimate, WorkspaceGenesis? workspaceGenesis, ChildWorkspaceList? childWorkspaces, FrameworkResponse? framework, CorrespondencePending? correspondencePending, IdentityProviderWitnessReady? identityProviderWitness, MaintenanceTicked? maintenanceTicked, ResidencyPressureRelieved? residencyPressureRelieved, MaintenanceScheduled? maintenanceScheduled, CustodyAdmission? custodyOffersAdmitted, LawPackageInspection? lawPackageInspection, LocalReadPending? localReadPending, FrontierRetained? frontierRetained, PeerSocketObserved? socketObserved, CustodyOfferBatchRequest? liveOffers, AuthenticationReadiness? authenticationReadiness, ApplicationPrepared? applicationPrepared, CorrespondenceRecovered? correspondenceRecovered, ReceivingGroupOpened? receivingGroupOpened, ReceivingGroupConvergence? receivingGroupConvergence, ApplicationModelAdopted? applicationModelAdopted, ResolvedWorkspaceName? resolvedWorkspaceName, ReferenceVersionReport? referenceVersions, WorkspaceOpening? workspaceOpening, HttpObligationDelivered? httpObligationDelivered, SessionBound? sessionBound, RuntimeRefusal? refused, HistoryAcquired? historyAcquired, LocalCopyDropPreview? localCopyDropPreview, LocalCopyDropScheduled? localCopyDropScheduled, ProviderOriginsConfigured? providerOriginsConfigured, WorkspaceFetch? workspaceFetch, ExportLawProductsResponse? lawProducts})
-
factory
-
RuntimeResponse.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- RuntimeResponse.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- applicationModelAdopted ↔ ApplicationModelAdopted
-
getter/setter pair
- applicationPrepared ↔ ApplicationPrepared
-
getter/setter pair
- authenticationReadiness ↔ AuthenticationReadiness
-
getter/setter pair
-
getter/setter pair
- blocked ↔ RuntimeBlocked
-
getter/setter pair
- childWorkspaces ↔ ChildWorkspaceList
-
getter/setter pair
- correspondencePending ↔ CorrespondencePending
-
getter/setter pair
- correspondenceRecovered ↔ CorrespondenceRecovered
-
getter/setter pair
- credentialsRefreshed ↔ CredentialsRefreshed
-
getter/setter pair
- custodyOffersAdmitted ↔ CustodyAdmission
-
getter/setter pair
- deadLetter ↔ DeadLetterResponse
-
getter/setter pair
- domainPrepared ↔ DomainPrepared
-
getter/setter pair
- failure ↔ RuntimeFailure
-
getter/setter pair
- framework ↔ FrameworkResponse
-
getter/setter pair
- frontierRetained ↔ FrontierRetained
-
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- historyAcquired ↔ HistoryAcquired
-
getter/setter pair
- httpObligationDelivered ↔ HttpObligationDelivered
-
getter/setter pair
- identityProviderWitness ↔ IdentityProviderWitnessReady
-
getter/setter pair
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - kernelCall ↔ CallResponse
-
getter/setter pair
- lawPackageInspection ↔ LawPackageInspection
-
getter/setter pair
- lawProducts ↔ ExportLawProductsResponse
-
getter/setter pair
- liveOffers ↔ CustodyOfferBatchRequest
-
getter/setter pair
- localCopyDropPreview ↔ LocalCopyDropPreview
-
getter/setter pair
- localCopyDropScheduled ↔ LocalCopyDropScheduled
-
getter/setter pair
- localReadPending ↔ LocalReadPending
-
getter/setter pair
- maintenanceScheduled ↔ MaintenanceScheduled
-
getter/setter pair
- maintenanceTicked ↔ MaintenanceTicked
-
getter/setter pair
- protocolVersion ↔ int
-
getter/setter pair
- providerOriginsConfigured ↔ ProviderOriginsConfigured
-
getter/setter pair
- realmClosed ↔ RealmClosed
-
getter/setter pair
- receivingGroupConvergence ↔ ReceivingGroupConvergence
-
getter/setter pair
- receivingGroupOpened ↔ ReceivingGroupOpened
-
getter/setter pair
- referenceVersions ↔ ReferenceVersionReport
-
getter/setter pair
- refused ↔ RuntimeRefusal
-
getter/setter pair
- remoteGeneratedOffer ↔ RemoteGeneratedOfferAccepted
-
getter/setter pair
- remoteOfferAdmission ↔ RemoteOfferAdmission
-
getter/setter pair
- requestId ↔ Int64
-
getter/setter pair
- residencyPressureRelieved ↔ ResidencyPressureRelieved
-
getter/setter pair
- resolvedWorkspaceName ↔ ResolvedWorkspaceName
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionBound ↔ SessionBound
-
getter/setter pair
- socketObserved ↔ PeerSocketObserved
-
getter/setter pair
- syncWorkspace ↔ SyncWorkspaceResponse
-
getter/setter pair
-
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- watchStarted ↔ WatchStarted
-
getter/setter pair
- watchStopped ↔ WatchStopped
-
getter/setter pair
- workspaceEffectsDelivered ↔ WorkspaceEffectsDelivered
-
getter/setter pair
- workspaceFetch ↔ WorkspaceFetch
-
getter/setter pair
- workspaceGenesis ↔ WorkspaceGenesis
-
getter/setter pair
- workspaceList ↔ WorkspaceList
-
getter/setter pair
- workspaceMoments ↔ WorkspaceMomentList
-
getter/setter pair
- workspaceOpening ↔ WorkspaceOpening
-
The addressed workspace is still being opened; the paper was not executed. Resend it
after the retry delay. No request holds an open.
getter/setter pair
- workspacePlacement ↔ WorkspacePlacementState
-
getter/setter pair
- workspaceStatus ↔ WorkspaceStatus
-
getter/setter pair
- workspaceTransferEstimate ↔ WorkspaceTransferEstimate
-
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearApplicationModelAdopted(
) → void -
clearApplicationPrepared(
) → void -
clearAuthenticationReadiness(
) → void -
clearAuthoringPreflight(
) → void -
clearBlocked(
) → void -
clearChildWorkspaces(
) → void -
clearCorrespondencePending(
) → void -
clearCorrespondenceRecovered(
) → void -
clearCredentialsRefreshed(
) → void -
clearCustodyOffersAdmitted(
) → void -
clearDeadLetter(
) → void -
clearDomainPrepared(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearFailure(
) → void -
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearFramework(
) → void -
clearFrontierRetained(
) → void -
clearHistoryAcquired(
) → void -
clearHttpObligationDelivered(
) → void -
clearIdentityProviderWitness(
) → void -
clearKernelCall(
) → void -
clearLawPackageInspection(
) → void -
clearLawProducts(
) → void -
clearLiveOffers(
) → void -
clearLocalCopyDropPreview(
) → void -
clearLocalCopyDropScheduled(
) → void -
clearLocalReadPending(
) → void -
clearMaintenanceScheduled(
) → void -
clearMaintenanceTicked(
) → void -
clearOutcome(
) → void -
clearProtocolVersion(
) → void -
clearProviderOriginsConfigured(
) → void -
clearRealmClosed(
) → void -
clearReceivingGroupConvergence(
) → void -
clearReceivingGroupOpened(
) → void -
clearReferenceVersions(
) → void -
clearRefused(
) → void -
clearRemoteGeneratedOffer(
) → void -
clearRemoteOfferAdmission(
) → void -
clearRequestId(
) → void -
clearResidencyPressureRelieved(
) → void -
clearResolvedWorkspaceName(
) → void -
clearSessionBound(
) → void -
clearSocketObserved(
) → void -
clearSyncWorkspace(
) → void -
clearWatchStarted(
) → void -
clearWatchStopped(
) → void -
clearWorkspaceEffectsDelivered(
) → void -
clearWorkspaceFetch(
) → void -
clearWorkspaceGenesis(
) → void -
clearWorkspaceList(
) → void -
clearWorkspaceMoments(
) → void -
clearWorkspaceOpening(
) → void -
clearWorkspacePlacement(
) → void -
clearWorkspaceStatus(
) → void -
clearWorkspaceTransferEstimate(
) → void -
clone(
) → RuntimeResponse - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(RuntimeResponse)) → RuntimeResponse -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → RuntimeResponse - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureApplicationModelAdopted(
) → ApplicationModelAdopted -
ensureApplicationPrepared(
) → ApplicationPrepared -
ensureAuthenticationReadiness(
) → AuthenticationReadiness -
ensureAuthoringPreflight(
) → AuthoringPreflightResult -
ensureBlocked(
) → RuntimeBlocked -
ensureChildWorkspaces(
) → ChildWorkspaceList -
ensureCorrespondencePending(
) → CorrespondencePending -
ensureCorrespondenceRecovered(
) → CorrespondenceRecovered -
ensureCredentialsRefreshed(
) → CredentialsRefreshed -
ensureCustodyOffersAdmitted(
) → CustodyAdmission -
ensureDeadLetter(
) → DeadLetterResponse -
ensureDomainPrepared(
) → DomainPrepared -
ensureFailure(
) → RuntimeFailure -
ensureFramework(
) → FrameworkResponse -
ensureFrontierRetained(
) → FrontierRetained -
ensureHistoryAcquired(
) → HistoryAcquired -
ensureHttpObligationDelivered(
) → HttpObligationDelivered -
ensureIdentityProviderWitness(
) → IdentityProviderWitnessReady -
ensureKernelCall(
) → CallResponse -
ensureLawPackageInspection(
) → LawPackageInspection -
ensureLawProducts(
) → ExportLawProductsResponse -
ensureLiveOffers(
) → CustodyOfferBatchRequest -
ensureLocalCopyDropPreview(
) → LocalCopyDropPreview -
ensureLocalCopyDropScheduled(
) → LocalCopyDropScheduled -
ensureLocalReadPending(
) → LocalReadPending -
ensureMaintenanceScheduled(
) → MaintenanceScheduled -
ensureMaintenanceTicked(
) → MaintenanceTicked -
ensureProviderOriginsConfigured(
) → ProviderOriginsConfigured -
ensureRealmClosed(
) → RealmClosed -
ensureReceivingGroupConvergence(
) → ReceivingGroupConvergence -
ensureReceivingGroupOpened(
) → ReceivingGroupOpened -
ensureReferenceVersions(
) → ReferenceVersionReport -
ensureRefused(
) → RuntimeRefusal -
ensureRemoteGeneratedOffer(
) → RemoteGeneratedOfferAccepted -
ensureRemoteOfferAdmission(
) → RemoteOfferAdmission -
ensureResidencyPressureRelieved(
) → ResidencyPressureRelieved -
ensureResolvedWorkspaceName(
) → ResolvedWorkspaceName -
ensureSessionBound(
) → SessionBound -
ensureSocketObserved(
) → PeerSocketObserved -
ensureSyncWorkspace(
) → SyncWorkspaceResponse -
ensureWatchStarted(
) → WatchStarted -
ensureWatchStopped(
) → WatchStopped -
ensureWorkspaceEffectsDelivered(
) → WorkspaceEffectsDelivered -
ensureWorkspaceFetch(
) → WorkspaceFetch -
ensureWorkspaceGenesis(
) → WorkspaceGenesis -
ensureWorkspaceList(
) → WorkspaceList -
ensureWorkspaceMoments(
) → WorkspaceMomentList -
ensureWorkspaceOpening(
) → WorkspaceOpening -
ensureWorkspacePlacement(
) → WorkspacePlacementState -
ensureWorkspaceStatus(
) → WorkspaceStatus -
ensureWorkspaceTransferEstimate(
) → WorkspaceTransferEstimate -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasApplicationModelAdopted(
) → bool -
hasApplicationPrepared(
) → bool -
hasAuthenticationReadiness(
) → bool -
hasAuthoringPreflight(
) → bool -
hasBlocked(
) → bool -
hasChildWorkspaces(
) → bool -
hasCorrespondencePending(
) → bool -
hasCorrespondenceRecovered(
) → bool -
hasCredentialsRefreshed(
) → bool -
hasCustodyOffersAdmitted(
) → bool -
hasDeadLetter(
) → bool -
hasDomainPrepared(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasFailure(
) → bool -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasFramework(
) → bool -
hasFrontierRetained(
) → bool -
hasHistoryAcquired(
) → bool -
hasHttpObligationDelivered(
) → bool -
hasIdentityProviderWitness(
) → bool -
hasKernelCall(
) → bool -
hasLawPackageInspection(
) → bool -
hasLawProducts(
) → bool -
hasLiveOffers(
) → bool -
hasLocalCopyDropPreview(
) → bool -
hasLocalCopyDropScheduled(
) → bool -
hasLocalReadPending(
) → bool -
hasMaintenanceScheduled(
) → bool -
hasMaintenanceTicked(
) → bool -
hasProtocolVersion(
) → bool -
hasProviderOriginsConfigured(
) → bool -
hasRealmClosed(
) → bool -
hasReceivingGroupConvergence(
) → bool -
hasReceivingGroupOpened(
) → bool -
hasReferenceVersions(
) → bool -
hasRefused(
) → bool -
hasRemoteGeneratedOffer(
) → bool -
hasRemoteOfferAdmission(
) → bool -
hasRequestId(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasResidencyPressureRelieved(
) → bool -
hasResolvedWorkspaceName(
) → bool -
hasSessionBound(
) → bool -
hasSocketObserved(
) → bool -
hasSyncWorkspace(
) → bool -
hasWatchStarted(
) → bool -
hasWatchStopped(
) → bool -
hasWorkspaceEffectsDelivered(
) → bool -
hasWorkspaceFetch(
) → bool -
hasWorkspaceGenesis(
) → bool -
hasWorkspaceList(
) → bool -
hasWorkspaceMoments(
) → bool -
hasWorkspaceOpening(
) → bool -
hasWorkspacePlacement(
) → bool -
hasWorkspaceStatus(
) → bool -
hasWorkspaceTransferEstimate(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
whichOutcome(
) → RuntimeResponse_Outcome -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited