RuntimeResponse class
- Available extensions
Constructors
- RuntimeResponse({int? protocolVersion, Int64? requestId, RuntimeFailure? failure, CallResponse? kernelCall, Connected? connected, WorkspaceList? workspaceList, WorkspaceSnapshot? workspaceSnapshot, SyncWorkspaceResponse? syncWorkspace, AutoSyncStarted? autoSyncStarted, AutoSyncStopped? autoSyncStopped, WatchStarted? watchStarted, WatchStopped? watchStopped, DomainPrepared? domainPrepared, CustodyBreakResolved? custodyBreakResolved, RealmClosed? realmClosed, RuntimeBlocked? blocked, RemoteOfferAdmission? remoteOfferAdmission, DeadLetterResponse? deadLetter, ModelLifecycleResponse? modelLifecycle, ApplicationCustodyEstablished? applicationCustodyEstablished})
-
factory
-
RuntimeResponse.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- RuntimeResponse.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- applicationCustodyEstablished ↔ ApplicationCustodyEstablished
-
getter/setter pair
- autoSyncStarted ↔ AutoSyncStarted
-
getter/setter pair
- autoSyncStopped ↔ AutoSyncStopped
-
getter/setter pair
- blocked ↔ RuntimeBlocked
-
getter/setter pair
- connected ↔ Connected
-
getter/setter pair
- custodyBreakResolved ↔ CustodyBreakResolved
-
getter/setter pair
- deadLetter ↔ DeadLetterResponse
-
getter/setter pair
- domainPrepared ↔ DomainPrepared
-
getter/setter pair
- failure ↔ RuntimeFailure
-
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - kernelCall ↔ CallResponse
-
getter/setter pair
- modelLifecycle ↔ ModelLifecycleResponse
-
getter/setter pair
- protocolVersion ↔ int
-
getter/setter pair
- realmClosed ↔ RealmClosed
-
getter/setter pair
- remoteOfferAdmission ↔ RemoteOfferAdmission
-
getter/setter pair
- requestId ↔ Int64
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- syncWorkspace ↔ SyncWorkspaceResponse
-
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- watchStarted ↔ WatchStarted
-
getter/setter pair
- watchStopped ↔ WatchStopped
-
getter/setter pair
- workspaceList ↔ WorkspaceList
-
getter/setter pair
- workspaceSnapshot ↔ WorkspaceSnapshot
-
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearApplicationCustodyEstablished(
) → void -
clearAutoSyncStarted(
) → void -
clearAutoSyncStopped(
) → void -
clearBlocked(
) → void -
clearConnected(
) → void -
clearCustodyBreakResolved(
) → void -
clearDeadLetter(
) → void -
clearDomainPrepared(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearFailure(
) → void -
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearKernelCall(
) → void -
clearModelLifecycle(
) → void -
clearOutcome(
) → void -
clearProtocolVersion(
) → void -
clearRealmClosed(
) → void -
clearRemoteOfferAdmission(
) → void -
clearRequestId(
) → void -
clearSyncWorkspace(
) → void -
clearWatchStarted(
) → void -
clearWatchStopped(
) → void -
clearWorkspaceList(
) → void -
clearWorkspaceSnapshot(
) → void -
clone(
) → RuntimeResponse - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(RuntimeResponse)) → RuntimeResponse -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → RuntimeResponse - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureApplicationCustodyEstablished(
) → ApplicationCustodyEstablished -
ensureAutoSyncStarted(
) → AutoSyncStarted -
ensureAutoSyncStopped(
) → AutoSyncStopped -
ensureBlocked(
) → RuntimeBlocked -
ensureConnected(
) → Connected -
ensureCustodyBreakResolved(
) → CustodyBreakResolved -
ensureDeadLetter(
) → DeadLetterResponse -
ensureDomainPrepared(
) → DomainPrepared -
ensureFailure(
) → RuntimeFailure -
ensureKernelCall(
) → CallResponse -
ensureModelLifecycle(
) → ModelLifecycleResponse -
ensureRealmClosed(
) → RealmClosed -
ensureRemoteOfferAdmission(
) → RemoteOfferAdmission -
ensureSyncWorkspace(
) → SyncWorkspaceResponse -
ensureWatchStarted(
) → WatchStarted -
ensureWatchStopped(
) → WatchStopped -
ensureWorkspaceList(
) → WorkspaceList -
ensureWorkspaceSnapshot(
) → WorkspaceSnapshot -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasApplicationCustodyEstablished(
) → bool -
hasAutoSyncStarted(
) → bool -
hasAutoSyncStopped(
) → bool -
hasBlocked(
) → bool -
hasConnected(
) → bool -
hasCustodyBreakResolved(
) → bool -
hasDeadLetter(
) → bool -
hasDomainPrepared(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasFailure(
) → bool -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasKernelCall(
) → bool -
hasModelLifecycle(
) → bool -
hasProtocolVersion(
) → bool -
hasRealmClosed(
) → bool -
hasRemoteOfferAdmission(
) → bool -
hasRequestId(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasSyncWorkspace(
) → bool -
hasWatchStarted(
) → bool -
hasWatchStopped(
) → bool -
hasWorkspaceList(
) → bool -
hasWorkspaceSnapshot(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
whichOutcome(
) → RuntimeResponse_Outcome -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited